@@ -9,7 +9,7 @@
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
  * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
- * @version   SVN: $Id: class.Linux.inc.php 389 2010-11-11 13:53:45Z jacky672 $
+ * @version   SVN: $Id: class.Linux.inc.php 422 2011-01-21 12:42:25Z jacky672 $
  * @link      http://phpsysinfo.sourceforge.net
  */
  /**
@@ -170,7 +170,9 @@ class Linux extends OS
             }
         }
         // we need a second value, wait 1 second befor getting (< 1 second no good value will occour)
-        sleep(1);
+        if(PSI_LOAD_BAR) {
+            sleep(1);
+        }
         if (CommonFunctions::rfts('/proc/stat', $buf)) {
             $lines = preg_split("/\n/", $buf, -1, PREG_SPLIT_NO_EMPTY);
             foreach ($lines as $line) {
@@ -209,7 +211,9 @@ class Linux extends OS
                     if (count($arrBuff) == 2) {
                         switch (strtolower($arrBuff[0])) {
                         case 'processor':
-                            $dev->setLoad($this->_parseProcStat('cpu'.trim($arrBuff[1])));
+                            if(PSI_LOAD_BAR) {
+                                $dev->setLoad($this->_parseProcStat('cpu'.trim($arrBuff[1])));
+                            }
                             break;
                         case 'model name':
                         case 'cpu':
@@ -233,6 +237,14 @@ class Linux extends OS
                         case 'cpu0bogo':
                             $dev->setBogomips($arrBuff[1]);
                             break;
+                        case 'flags':
+                            if(preg_match("/vmx/",$arrBuff[1])) {
+                                $dev->setVirt("vmx");
+                            }
+                            else if(preg_match("/smv/",$arrBuff[1])) {
+                                $dev->setVirt("smv");
+                            }
+                            break;
                         }
                     }
                 }
