@@ -9,7 +9,7 @@
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
  * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
- * @version   SVN: $Id: class.XML.inc.php 389 2010-11-11 13:53:45Z jacky672 $
+ * @version   SVN: $Id: class.XML.inc.php 423 2011-01-21 12:53:46Z jacky672 $
  * @link      http://phpsysinfo.sourceforge.net
  */
  /**
@@ -209,6 +209,9 @@ class XML
             if ($oneCpu->getCache() !== null) {
                 $tmp->addAttribute('Cache', $oneCpu->getCache());
             }
+            if ($oneCpu->getVirt() !== null) {
+                $tmp->addAttribute('Virt', $oneCpu->getVirt());
+            }
             if ($oneCpu->getBogomips() !== null) {
                 $tmp->addAttribute('Bogomips', $oneCpu->getBogomips());
             }
@@ -487,7 +490,7 @@ class XML
         $root = $dom->createElement("tns:phpsysinfo");
         $root->setAttribute('xmlns:tns', 'http://phpsysinfo.sourceforge.net/');
         $root->setAttribute('xmlns:xsi', 'http://www.w3.org/2001/XMLSchema-instance');
-        $root->setAttribute('xsi:schemaLocation', 'http://phpsysinfo.sourceforge.net/ phpsysinfo3.xsd');
+        $root->setAttribute('xsi:schemaLocation', 'http://phpsysinfo.sourceforge.net/phpsysinfo3.xsd');
         $dom->appendChild($root);
         $this->_xml = new SimpleXMLExtended(simplexml_import_dom($dom), $this->_sysinfo->getEncoding());
         
