@@ -18,7 +18,7 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 //
-// $Id: phpsysinfo.js 403 2010-11-15 18:44:31Z jacky672 $
+// $Id: phpsysinfo.js 419 2011-01-18 08:28:56Z jacky672 $
 //
 
 /*global $, jQuery */
@@ -586,16 +586,17 @@ function refreshVitals(xml) {
 function fillCpu(xml, tree, rootposition, collapsed) {
     var cpucount = 0, html = "";
     $("Hardware CPU CpuCore", xml).each(function getCpuCore(cpuCoreId) {
-        var model = "", speed = 0, bus = 0, cache = 0, bogo = 0, temp = 0, load = 0, cpucoreposition = 0;
+        var model = "", speed = 0, bus = 0, cache = 0, bogo = 0, temp = 0, load = 0, cpucoreposition = 0, virt = "";
         cpucount += 1;
         model = $(this).attr("Model");
         speed = parseInt($(this).attr("CpuSpeed"), 10);
         cache = parseInt($(this).attr("Cache"), 10);
+        virt = $(this).attr("Virt");
         bus = parseInt($(this).attr("BusSpeed"), 10);
         temp = parseInt($(this).attr("Cputemp"), 10);
         bogo = parseInt($(this).attr("Bogomips"), 10);
         load = parseInt($(this).attr("Load"), 10);
-        
+
         html += "<tr><td colspan=\"2\">" + model + "</td></tr>\n";
         cpucoreposition = tree.push(rootposition);
         if (!isNaN(speed)) {
@@ -607,6 +608,10 @@ function fillCpu(xml, tree, rootposition, collapsed) {
             html += "<tr><td style=\"width:50%\">" + genlang(15, true) + ":</td><td>" + formatBytes(cache) + "</td></tr>\n";
             tree.push(cpucoreposition);
         }
+        if (virt != undefined) {
+            html += "<tr><td style=\"width:50%\">" + genlang(94, true) + ":</td><td>" + virt + "</td></tr>\n";
+            tree.push(cpucoreposition);
+        }
         if (!isNaN(bus)) {
             html += "<tr><td style=\"width:50%\">" + genlang(14, true) + ":</td><td>" + formatHertz(bus) + "</td></tr>\n";
             tree.push(cpucoreposition);
@@ -709,7 +714,7 @@ function refreshHardware(xml) {
         column: 0,
         striped: true,
         highlight: false,
-        state: true
+        state: false
     });
 }
 
@@ -830,7 +835,7 @@ function refreshMemory(xml) {
         column: 0,
         striped: true,
         highlight: false,
-        state: true
+        state: false
     });
     
 }
@@ -1056,7 +1061,7 @@ function refreshUps(xml) {
             column: 0,
             striped: true,
             highlight: false,
-            state: true
+            state: false
         });
         $("#ups").show();
     }
